/*----------------------------------------------------------------------------
 Copyright:      Radig Ulrich  mailto: mail@ulrichradig.de
 Author:         Radig Ulrich
 Remarks:        
 known Problems: none
 Version:        24.10.2007
 Description:    RS232 Routinen
----------------------------------------------------------------------------*/

#include <avr/io.h>

//Die Baud_Rate der Seriellen Schnittstelle ist 9600 Baud
#define BAUD_RATE 9600		

#define USR UCSR0A
#define UCR UCSR0B
#define UDR UDR0
#define UBRR UBRR0L
#define SIG_USART_RECV SIG_USART0_RECV









#ifndef _UART_H
	#define _UART_H

#define USART_ECHO	1

#define BUFFER_SIZE	50

volatile unsigned char buffercounter;
char usart_rx_buffer[BUFFER_SIZE];

struct {
		volatile unsigned char usart_ready:1;
		volatile unsigned char usart_rx_ovl:1;
		}usart_status ;

//----------------------------------------------------------------------------

#include <avr/interrupt.h>
#include <stdlib.h>
#include <stdarg.h>
#include <ctype.h>
#include <string.h>
#include <avr/io.h>

//----------------------------------------------------------------------------

//Der Quarz auf dem Saeco Handy Programmer
#ifndef SYSCLK
		#define SYSCLK 16000000UL
#endif //SYSCLK	

//Anpassen der seriellen Schnittstellen Register wenn ein ATMega128 benutzt wird
#if defined (__AVR_ATmega128__)
	#define USR UCSR0A
	#define UCR UCSR0B
	#define UDR UDR0
	#define UBRR UBRR0L
	#define SIG_USART_RECV SIG_USART0_RECV
#endif

#if defined (__AVR_ATmega644__)
	#define USR UCSR0A
	#define UCR UCSR0B
	#define UBRR UBRR0L
	#define EICR EICRB
	#define TXEN TXEN0
	#define RXEN RXEN0
	#define RXCIE RXCIE0
	#define UDR UDR0
	#define UDRE UDRE0
#endif

#if defined (__AVR_ATmega32__)
	#define USR UCSRA
	#define UCR UCSRB
	#define UBRR UBRRL
	#define EICR EICRB
#endif

#if defined (__AVR_ATmega8__)
	#define USR UCSRA
	#define UCR UCSRB
	#define UBRR UBRRL
#endif

#if defined (__AVR_ATmega88__)
	#define USR UCSR0A
	#define UCR UCSR0B
	#define UBRR UBRR0L
	#define TXEN TXEN0
	#define UDR UDR0
	#define UDRE UDRE0
#endif
//----------------------------------------------------------------------------

void usart_init(unsigned int baudrate); 
int usart_write_char(char c);
int usart_write_char1(char c);
void usart_write_str(char *str);
void usart_write_str1(char *str);
void usart_write (char *Buffer,...);

//----------------------------------------------------------------------------

#endif //_UART_H

